@@ -15,17 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
- */
-
-/*
- * Modified by the gedit Team, 2005. See the AUTHORS file for a
- * list of people on the gedit Team.
- * See the ChangeLog files for a list of changes.
- *
- * $Id$
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -38,6 +28,7 @@
 #include <locale.h>
 
 #include <glib/gi18n.h>
+#include <gio/gio.h>
 #include <libpeas/peas-extension-set.h>
 #include <gtksourceview/gtksource.h>
 
@@ -57,6 +48,7 @@
 #include "gedit-plugins-engine.h"
 #include "gedit-commands.h"
 #include "gedit-preferences-dialog.h"
+#include "gedit-tab.h"
 
 #ifndef ENABLE_GVFS_METADATA
 #include "gedit-metadata-manager.h"
@@ -86,7 +78,10 @@ struct _GeditAppPrivate
 	GSettings         *ui_settings;
 	GSettings         *window_settings;
 
+	GMenuModel        *window_menu;
+
 	PeasExtensionSet  *extensions;
+	GNetworkMonitor   *monitor;
 };
 
 static gboolean help = FALSE;
@@ -215,6 +210,8 @@ gedit_app_dispose (GObject *object)
 
 	g_clear_object (&app->priv->engine);
 
+	g_clear_object (&app->priv->window_menu);
+
 	G_OBJECT_CLASS (gedit_app_parent_class)->dispose (object);
 }
 
@@ -413,6 +410,27 @@ extension_removed (PeasExtensionSet *extensions,
 	gedit_app_activatable_deactivate (GEDIT_APP_ACTIVATABLE (exten));
 }
 
+static gboolean
+gedit_app_has_app_menu (GeditApp *app)
+{
+	GtkSettings *gtk_settings;
+	gboolean show_app_menu;
+	gboolean show_menubar;
+
+	/* We have three cases:
+	 * - GNOME 3: show-app-menu true, show-menubar false -> use the app menu
+	 * - Unity, OSX: show-app-menu and show-menubar true -> use the normal menu
+	 * - Other WM, Windows: show-app-menu and show-menubar false -> use the normal menu
+	 */
+	gtk_settings = gtk_settings_get_default ();
+	g_object_get (G_OBJECT (gtk_settings),
+	              "gtk-shell-shows-app-menu", &show_app_menu,
+	              "gtk-shell-shows-menubar", &show_menubar,
+	              NULL);
+
+	return show_app_menu && !show_menubar;
+}
+
 static void
 gedit_app_startup (GApplication *application)
 {
@@ -427,6 +445,7 @@ gedit_app_startup (GApplication *application)
 	GError *error = NULL;
 	GFile *css_file;
 	GtkCssProvider *provider;
+	GtkBuilder *builder;
 
 	G_APPLICATION_CLASS (gedit_app_parent_class)->startup (application);
 
@@ -477,31 +496,35 @@ gedit_app_startup (GApplication *application)
 	                                 G_N_ELEMENTS (app_entries),
 	                                 app);
 
-	/* app menu */
-	if (_gedit_app_has_app_menu (app))
+	/* load menu model */
+	builder = gtk_builder_new ();
+	if (!gtk_builder_add_from_resource (builder,
+	                                    "/org/gnome/gedit/ui/gedit-menu.ui",
+	                                    &error))
+	{
+		g_warning ("loading menu builder file: %s", error->message);
+		g_error_free (error);
+	}
+	else
 	{
-		GtkBuilder *builder;
 
-		builder = gtk_builder_new ();
-		if (!gtk_builder_add_from_resource (builder,
-		                                    "/org/gnome/gedit/ui/gedit-menu.ui",
-		                                    &error))
+		if (gedit_app_has_app_menu (app))
 		{
-			g_warning ("loading menu builder file: %s", error->message);
-			g_error_free (error);
+			GMenuModel *appmenu;
+
+			appmenu = G_MENU_MODEL (gtk_builder_get_object (builder, "appmenu"));
+			gtk_application_set_app_menu (GTK_APPLICATION (application), appmenu);
+
+			app->priv->window_menu = G_MENU_MODEL (gtk_builder_get_object (builder, "gear_menu_withappmenu"));
 		}
 		else
 		{
-			GMenuModel *app_menu;
-
-			app_menu = G_MENU_MODEL (gtk_builder_get_object (builder, "appmenu"));
-			gtk_application_set_app_menu (GTK_APPLICATION (application),
-			                              app_menu);
+			app->priv->window_menu = G_MENU_MODEL (gtk_builder_get_object (builder, "gear_menu_noappmenu"));
 		}
-
-		g_object_unref (builder);
 	}
 
+	g_object_unref (builder);
+
 	/* Accelerators */
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
 	                                 "<Primary>Q", "app.quit", NULL);
@@ -513,49 +536,49 @@ gedit_app_startup (GApplication *application)
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
 	                                 "<Primary>S", "win.save", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary><Shift>S", "win.save_as", NULL);
+	                                 "<Primary><Shift>S", "win.save-as", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary><Shift>L", "win.save_all", NULL);
+	                                 "<Primary><Shift>L", "win.save-all", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary>T", "win.new_tab", NULL);
+	                                 "<Primary>T", "win.new-tab", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
 	                                 "<Primary>W", "win.close", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary><Shift>W", "win.close_all", NULL);
+	                                 "<Primary><Shift>W", "win.close-all", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
 	                                 "<Primary>P", "win.print", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
 	                                 "<Primary>F", "win.find", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary>G", "win.find_next", NULL);
+	                                 "<Primary>G", "win.find-next", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary><Shift>G", "win.find_prev", NULL);
+	                                 "<Primary><Shift>G", "win.find-prev", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
 	                                 "<Primary>H", "win.replace", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary><Shift>K", "win.clear_highlight", NULL);
+	                                 "<Primary><Shift>K", "win.clear-highlight", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary>I", "win.goto_line", NULL);
+	                                 "<Primary>I", "win.goto-line", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "F9", "win.side_panel", NULL);
+	                                 "F9", "win.side-panel", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary>F9", "win.bottom_panel", NULL);
+	                                 "<Primary>F9", "win.bottom-panel", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
 	                                 "F11", "win.fullscreen", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary><Alt>N", "win.new_tab_group", NULL);
+	                                 "<Primary><Alt>N", "win.new-tab-group", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
 	                                 "<Primary><Shift><Alt>Page_Up",
-	                                 "win.previous_tab_group", NULL);
+	                                 "win.previous-tab-group", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
 	                                 "<Primary><Shift><Alt>Page_Down",
-	                                 "win.next_tab_group", NULL);
+	                                 "win.next-tab-group", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
 	                                 "<Primary><Alt>Page_Up",
-	                                 "win.previous_document", NULL);
+	                                 "win.previous-document", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
 	                                 "<Primary><Alt>Page_Down",
-	                                 "win.next_document", NULL);
+	                                 "win.next-document", NULL);
 
 	/* Load custom css */
 	error = NULL;
@@ -795,6 +818,33 @@ get_option_context (void)
 	return context;
 }
 
+static gboolean
+option_context_parse (GOptionContext  *context,
+                      gchar          **arguments,
+                      GError         **error)
+{
+	gint argc;
+	gchar **argv;
+	gint i;
+	gboolean ret;
+
+	/* We have to make an extra copy of the array, since g_option_context_parse()
+	 * assumes that it can remove strings from the array without freeing them.
+	 */
+	argc = g_strv_length (arguments);
+	argv = g_new (gchar *, argc);
+	for (i = 0; i < argc; i++)
+	{
+		argv[i] = arguments[i];
+	}
+
+	ret = g_option_context_parse (context, &argc, &argv, error);
+
+	g_free (argv);
+
+	return ret;
+}
+
 static void
 clear_options (void)
 {
@@ -861,7 +911,7 @@ gedit_app_command_line (GApplication            *application,
 	/* Avoid exit() on the main instance */
 	g_option_context_set_help_enabled (context, FALSE);
 
-	if (!g_option_context_parse_strv (context, &arguments, &error))
+	if (!option_context_parse (context, arguments, &error))
 	{
 		/* We should never get here since parsing would have
 		 * failed on the client side... */
@@ -954,7 +1004,7 @@ gedit_app_local_command_line (GApplication   *application,
 	/* Handle some of the option without contacting the main instance */
 	context = get_option_context ();
 
-	if (!g_option_context_parse_strv (context, arguments, &error))
+	if (!option_context_parse (context, *arguments, &error))
 	{
 		g_printerr (_("%s\nRun '%s --help' to see a full list of available command line options.\n"),
 		           error->message, (*arguments)[0]);
@@ -1302,6 +1352,39 @@ load_print_settings (GeditApp *app)
 		app->priv->print_settings = gtk_print_settings_new ();
 }
 
+static void
+get_network_available (GNetworkMonitor *monitor,
+		       gboolean         available,
+		       GeditApp        *app)
+{
+	gboolean enable;
+	GList *windows, *w;
+
+	enable = g_network_monitor_get_network_available (monitor);
+
+	windows = gtk_application_get_windows (GTK_APPLICATION (app));
+
+	for (w = windows; w != NULL; w = w->next)
+	{
+		GeditWindow *window = GEDIT_WINDOW (w->data);
+
+		if (GEDIT_IS_WINDOW (window))
+		{
+			GList *tabs, *t;
+
+			tabs = _gedit_window_get_all_tabs (window);
+
+			for (t = tabs; t != NULL; t = t->next)
+			{
+				_gedit_tab_set_network_available (GEDIT_TAB (t->data),
+					                          enable);
+			}
+
+			g_list_free (tabs);
+		}
+	}
+}
+
 static void
 gedit_app_init (GeditApp *app)
 {
@@ -1309,6 +1392,12 @@ gedit_app_init (GeditApp *app)
 
 	g_set_application_name ("gedit");
 	gtk_window_set_default_icon_name ("accessories-text-editor");
+
+	app->priv->monitor = g_network_monitor_get_default ();
+	g_signal_connect (app->priv->monitor,
+			  "network-changed",
+			  G_CALLBACK (get_network_available),
+			  app);
 }
 
 /* Generates a unique string for a window role */
@@ -1408,8 +1497,11 @@ gedit_app_get_documents	(GeditApp *app)
 	windows = gtk_application_get_windows (GTK_APPLICATION (app));
 	for (l = windows; l != NULL; l = g_list_next (l))
 	{
-		res = g_list_concat (res,
-				     gedit_window_get_documents (GEDIT_WINDOW (l->data)));
+		if (GEDIT_IS_WINDOW (l->data))
+		{
+			res = g_list_concat (res,
+			                     gedit_window_get_documents (GEDIT_WINDOW (l->data)));
+		}
 	}
 
 	return res;
@@ -1435,8 +1527,11 @@ gedit_app_get_views (GeditApp *app)
 	windows = gtk_application_get_windows (GTK_APPLICATION (app));
 	for (l = windows; l != NULL; l = g_list_next (l))
 	{
-		res = g_list_concat (res,
-				     gedit_window_get_views (GEDIT_WINDOW (l->data)));
+		if (GEDIT_IS_WINDOW (l->data))
+		{
+			res = g_list_concat (res,
+			                     gedit_window_get_views (GEDIT_WINDOW (l->data)));
+		}
 	}
 
 	return res;
@@ -1497,6 +1592,32 @@ gedit_app_process_window_event (GeditApp    *app,
     return FALSE;
 }
 
+
+static GMenuModel *
+find_extension_point_section (GMenuModel  *model,
+                              const gchar *extension_point)
+{
+	gint i, n_items;
+	GMenuModel *section = NULL;
+
+	n_items = g_menu_model_get_n_items (model);
+
+	for (i = 0; i < n_items && !section; i++)
+	{
+		gchar *id = NULL;
+
+		if (g_menu_model_get_item_attribute (model, i, "id", "s", &id) &&
+		    strcmp (id, extension_point) == 0)
+		{
+			section = g_menu_model_get_item_link (model, i, G_MENU_LINK_SECTION);
+		}
+
+		g_free (id);
+	}
+
+	return section;
+}
+
 static void
 app_lockdown_changed (GeditApp *app)
 {
@@ -1596,27 +1717,39 @@ _gedit_app_get_settings (GeditApp *app)
 	return app->priv->settings;
 }
 
-gboolean
-_gedit_app_has_app_menu (GeditApp *app)
+GMenuModel *
+_gedit_app_get_window_menu (GeditApp *app)
 {
-	GtkSettings *gtk_settings;
-	gboolean show_app_menu;
-	gboolean show_menubar;
+	g_return_val_if_fail (GEDIT_IS_APP (app), NULL);
 
-	g_return_val_if_fail (GEDIT_IS_APP (app), FALSE);
+	return app->priv->window_menu;
+}
 
-	/* We have three cases:
-	 * - GNOME 3: show-app-menu true, show-menubar false -> use the app menu
-	 * - Unity, OSX: show-app-menu and show-menubar true -> use the normal menu
-	 * - Other WM, Windows: show-app-menu and show-menubar false -> use the normal menu
-	 */
-	gtk_settings = gtk_settings_get_default ();
-	g_object_get (G_OBJECT (gtk_settings),
-	              "gtk-shell-shows-app-menu", &show_app_menu,
-	              "gtk-shell-shows-menubar", &show_menubar,
-	              NULL);
+GeditMenuExtension *
+_gedit_app_extend_menu (GeditApp    *app,
+                       const gchar *extension_point)
+{
+	GMenuModel *model;
+	GMenuModel *section;
 
-	return show_app_menu && !show_menubar;
+	g_return_val_if_fail (GEDIT_IS_APP (app), NULL);
+	g_return_val_if_fail (extension_point != NULL, NULL);
+
+	/* First look in the window menu */
+	section = find_extension_point_section (app->priv->window_menu, extension_point);
+
+	/* otherwise look in the app menu */
+	if (section == NULL)
+	{
+		model = gtk_application_get_app_menu (GTK_APPLICATION (app));
+
+		if (model != NULL)
+		{
+			section = find_extension_point_section (model, extension_point);
+		}
+	}
+
+	return section != NULL ? _gedit_menu_extension_new (G_MENU (section)) : NULL;
 }
 
 /* ex:set ts=8 noet: */
