@@ -15,17 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
- */
-
-/*
- * Modified by the gedit Team, 2005. See the AUTHORS file for a
- * list of people on the gedit Team.
- * See the ChangeLog files for a list of changes.
- *
- * $Id$
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __GEDIT_APP_H__
@@ -34,6 +24,7 @@
 #include <gtk/gtk.h>
 
 #include <gedit/gedit-window.h>
+#include <gedit/gedit-menu-extension.h>
 
 G_BEGIN_DECLS
 
@@ -144,7 +135,10 @@ void			 _gedit_app_set_default_print_settings	(GeditApp         *app,
 
 GObject			*_gedit_app_get_settings		(GeditApp  *app);
 
-gboolean		 _gedit_app_has_app_menu		(GeditApp  *app);
+GMenuModel		*_gedit_app_get_window_menu		(GeditApp  *app);
+
+GeditMenuExtension	*_gedit_app_extend_menu			(GeditApp    *app,
+								 const gchar *extension_point);
 
 G_END_DECLS
 
