@@ -16,17 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
- */
-
-/*
- * Modified by the gedit Team, 2001-2003. See the AUTHORS file for a
- * list of people on the gedit Team.
- * See the ChangeLog files for a list of changes.
- *
- * $Id$
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -861,13 +851,9 @@ install_scheme_clicked (GtkButton              *button,
 					       GTK_WINDOW (dlg),
 					       GTK_FILE_CHOOSER_ACTION_OPEN,
 					       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					       _("A_dd Scheme"), GTK_RESPONSE_ACCEPT,
 					       NULL);
 
-	gedit_dialog_add_button (GTK_DIALOG (chooser),
-				 _("A_dd Scheme"),
-				 GTK_STOCK_ADD,
-				 GTK_RESPONSE_ACCEPT);
-
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (chooser), TRUE);
 
 	/* Filters */
