@@ -15,17 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
- */
-
-/*
- * Modified by the gedit Team, 2005. See the AUTHORS file for a
- * list of people on the gedit Team.
- * See the ChangeLog files for a list of changes.
- *
- * $Id$
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __GEDIT_WINDOW_PRIVATE_H__
@@ -55,6 +45,7 @@ struct _GeditWindowPrivate
 	GeditMultiNotebook *multi_notebook;
 
 	GtkWidget      *side_panel;
+	GtkWidget      *bottom_panel_box;
 	GtkWidget      *bottom_panel;
 
 	GtkWidget      *hpaned;
@@ -91,9 +82,6 @@ struct _GeditWindowPrivate
 	GtkWidget      *open_button;
 	GtkWidget      *open_menu;
 	GtkMenuButton  *gear_button;
-	GMenuModel     *gear_menu;
-	GMenuModel     *gear_menu_win;
-	GMenuModel     *gear_menu_app;
 
 	/* recent files */
 
