@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -31,18 +30,19 @@
 #include <pango/pango-break.h>
 #include <gmodule.h>
 
+#include <gedit/gedit-app.h>
 #include <gedit/gedit-window.h>
-#include <gedit/gedit-window-activatable.h>
 #include <gedit/gedit-debug.h>
 #include <gedit/gedit-utils.h>
 #include <gedit/gedit-menu-extension.h>
+#include <gedit/gedit-app-activatable.h>
+#include <gedit/gedit-window-activatable.h>
 
 struct _GeditDocinfoPluginPrivate
 {
 	GeditWindow *window;
 
 	GSimpleAction *action;
-	GeditMenuExtension *menu;
 
 	GtkWidget *dialog;
 	GtkWidget *file_name_label;
@@ -63,20 +63,27 @@ struct _GeditDocinfoPluginPrivate
 	GtkWidget *selected_chars_label;
 	GtkWidget *selected_chars_ns_label;
 	GtkWidget *selected_bytes_label;
+
+	GeditApp  *app;
+	GeditMenuExtension *menu_ext;
 };
 
 enum
 {
 	PROP_0,
-	PROP_WINDOW
+	PROP_WINDOW,
+	PROP_APP
 };
 
+static void gedit_app_activatable_iface_init (GeditAppActivatableInterface *iface);
 static void gedit_window_activatable_iface_init (GeditWindowActivatableInterface *iface);
 
 G_DEFINE_DYNAMIC_TYPE_EXTENDED (GeditDocinfoPlugin,
 				gedit_docinfo_plugin,
 				PEAS_TYPE_EXTENSION_BASE,
 				0,
+				G_IMPLEMENT_INTERFACE_DYNAMIC (GEDIT_TYPE_APP_ACTIVATABLE,
+							       gedit_app_activatable_iface_init)
 				G_IMPLEMENT_INTERFACE_DYNAMIC (GEDIT_TYPE_WINDOW_ACTIVATABLE,
 							       gedit_window_activatable_iface_init))
 
@@ -438,8 +445,9 @@ gedit_docinfo_plugin_dispose (GObject *object)
 	gedit_debug_message (DEBUG_PLUGINS, "GeditDocinfoPlugin dispose");
 
 	g_clear_object (&plugin->priv->action);
-	g_clear_object (&plugin->priv->menu);
 	g_clear_object (&plugin->priv->window);
+	g_clear_object (&plugin->priv->menu_ext);
+	g_clear_object (&plugin->priv->app);
 
 	G_OBJECT_CLASS (gedit_docinfo_plugin_parent_class)->dispose (object);
 }
@@ -466,7 +474,9 @@ gedit_docinfo_plugin_set_property (GObject      *object,
 		case PROP_WINDOW:
 			plugin->priv->window = GEDIT_WINDOW (g_value_dup_object (value));
 			break;
-
+		case PROP_APP:
+			plugin->priv->app = GEDIT_APP (g_value_dup_object (value));
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 			break;
@@ -486,7 +496,9 @@ gedit_docinfo_plugin_get_property (GObject    *object,
 		case PROP_WINDOW:
 			g_value_set_object (value, plugin->priv->window);
 			break;
-
+		case PROP_APP:
+			g_value_set_object (value, plugin->priv->app);
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 			break;
@@ -516,7 +528,7 @@ update_ui (GeditDocinfoPlugin *plugin)
 }
 
 static void
-gedit_docinfo_plugin_activate (GeditWindowActivatable *activatable)
+gedit_docinfo_plugin_app_activate (GeditAppActivatable *activatable)
 {
 	GeditDocinfoPluginPrivate *priv;
 	GMenuItem *item;
@@ -525,23 +537,44 @@ gedit_docinfo_plugin_activate (GeditWindowActivatable *activatable)
 
 	priv = GEDIT_DOCINFO_PLUGIN (activatable)->priv;
 
+	priv->menu_ext = gedit_app_activatable_extend_menu (activatable, "tools-section");
+	item = g_menu_item_new (_("_Document Statistics"), "win.docinfo");
+	gedit_menu_extension_append_menu_item (priv->menu_ext, item);
+	g_object_unref (item);
+}
+
+static void
+gedit_docinfo_plugin_app_deactivate (GeditAppActivatable *activatable)
+{
+	GeditDocinfoPluginPrivate *priv;
+
+	gedit_debug (DEBUG_PLUGINS);
+
+	priv = GEDIT_DOCINFO_PLUGIN (activatable)->priv;
+
+	g_clear_object (&priv->menu_ext);
+}
+
+static void
+gedit_docinfo_plugin_window_activate (GeditWindowActivatable *activatable)
+{
+	GeditDocinfoPluginPrivate *priv;
+
+	gedit_debug (DEBUG_PLUGINS);
+
+	priv = GEDIT_DOCINFO_PLUGIN (activatable)->priv;
+
 	priv->action = g_simple_action_new ("docinfo", NULL);
 	g_signal_connect (priv->action, "activate",
 	                  G_CALLBACK (docinfo_cb), activatable);
 	g_action_map_add_action (G_ACTION_MAP (priv->window),
 	                         G_ACTION (priv->action));
 
-	priv->menu = gedit_window_activatable_extend_gear_menu (activatable,
-	                                                        "ext9");
-	item = g_menu_item_new (_("_Document Statistics"), "win.docinfo");
-	gedit_menu_extension_append_menu_item (priv->menu, item);
-	g_object_unref (item);
-
 	update_ui (GEDIT_DOCINFO_PLUGIN (activatable));
 }
 
 static void
-gedit_docinfo_plugin_deactivate (GeditWindowActivatable *activatable)
+gedit_docinfo_plugin_window_deactivate (GeditWindowActivatable *activatable)
 {
 	GeditDocinfoPluginPrivate *priv;
 
@@ -553,7 +586,7 @@ gedit_docinfo_plugin_deactivate (GeditWindowActivatable *activatable)
 }
 
 static void
-gedit_docinfo_plugin_update_state (GeditWindowActivatable *activatable)
+gedit_docinfo_plugin_window_update_state (GeditWindowActivatable *activatable)
 {
 	gedit_debug (DEBUG_PLUGINS);
 
@@ -571,16 +604,24 @@ gedit_docinfo_plugin_class_init (GeditDocinfoPluginClass *klass)
 	object_class->get_property = gedit_docinfo_plugin_get_property;
 
 	g_object_class_override_property (object_class, PROP_WINDOW, "window");
+	g_object_class_override_property (object_class, PROP_APP, "app");
 
 	g_type_class_add_private (klass, sizeof (GeditDocinfoPluginPrivate));
 }
 
+static void
+gedit_app_activatable_iface_init (GeditAppActivatableInterface *iface)
+{
+	iface->activate = gedit_docinfo_plugin_app_activate;
+	iface->deactivate = gedit_docinfo_plugin_app_deactivate;
+}
+
 static void
 gedit_window_activatable_iface_init (GeditWindowActivatableInterface *iface)
 {
-	iface->activate = gedit_docinfo_plugin_activate;
-	iface->deactivate = gedit_docinfo_plugin_deactivate;
-	iface->update_state = gedit_docinfo_plugin_update_state;
+	iface->activate = gedit_docinfo_plugin_window_activate;
+	iface->deactivate = gedit_docinfo_plugin_window_deactivate;
+	iface->update_state = gedit_docinfo_plugin_window_update_state;
 }
 
 static void
@@ -594,6 +635,9 @@ peas_register_types (PeasObjectModule *module)
 {
 	gedit_docinfo_plugin_register_type (G_TYPE_MODULE (module));
 
+	peas_object_module_register_extension_type (module,
+						    GEDIT_TYPE_APP_ACTIVATABLE,
+						    GEDIT_TYPE_DOCINFO_PLUGIN);
 	peas_object_module_register_extension_type (module,
 						    GEDIT_TYPE_WINDOW_ACTIVATABLE,
 						    GEDIT_TYPE_DOCINFO_PLUGIN);
