@@ -25,13 +25,12 @@ from .outputpanel import OutputPanel
 from .capture import Capture
 from .functions import *
 
-class ToolMenu(object):
-    def __init__(self, library, window, panel, menu):
-        super(ToolMenu, self).__init__()
+class ToolActions(object):
+    def __init__(self, library, window, panel):
+        super(ToolActions, self).__init__()
         self._library = library
         self._window = window
         self._panel = panel
-        self._menu = menu
         self._action_tools = {}
 
         self.update()
@@ -40,25 +39,11 @@ class ToolMenu(object):
         self.remove()
 
     def remove(self):
-        self._menu.remove_all()
-
         for name, tool in self._action_tools.items():
             self._window.remove_action(name)
-
-            if tool.shortcut:
-                app = Gio.Application.get_default()
-                app.remove_accelerator(tool.shortcut)
         self._action_tools = {}
 
-    def _insert_directory(self, directory, menu):
-        for d in sorted(directory.subdirs, key=lambda x: x.name.lower()):
-            submenu = Gio.Menu()
-            menu.append_submenu(d.name.replace('_', '__'), submenu)
-            section = Gio.Menu()
-            submenu.append_section(None, section)
-
-            self._insert_directory(d, section)
-
+    def _insert_directory(self, directory):
         for tool in sorted(directory.tools, key=lambda x: x.name.lower()):
             action_name = 'external-tool_%X_%X' % (id(tool), id(tool.name))
             self._action_tools[action_name] = tool
@@ -67,17 +52,9 @@ class ToolMenu(object):
             action.connect('activate', capture_menu_action, self._window, self._panel, tool)
             self._window.add_action(action)
 
-            item = Gio.MenuItem.new(tool.name.replace('_', '__'), "win.%s" % action_name)
-            item.set_attribute_value("hidden-when", GLib.Variant.new_string("action-disabled"))
-            menu.append_item(item)
-
-            if tool.shortcut:
-                app = Gio.Application.get_default()
-                app.add_accelerator(tool.shortcut, "win.%s" % action_name, None)
-
     def update(self):
         self.remove()
-        self._insert_directory(self._library.tree, self._menu)
+        self._insert_directory(self._library.tree)
         self.filter(self._window.get_active_document())
 
     def filter_language(self, language, item):
@@ -127,49 +104,36 @@ class WindowActivatable(GObject.Object, Gedit.WindowActivatable):
         GObject.Object.__init__(self)
         self._manager = None
         self._manager_default_size = None
-        self.menu = None
+        self.actions = None
 
     def do_activate(self):
-        # Ugly hack... we need to get access to the activatable to update the menuitems
+        # Ugly hack... we need to get access to the activatable to update the menu actions
         self.window._external_tools_window_activatable = self
         self._library = ToolLibrary()
 
-        action = Gio.SimpleAction(name="manage_tools")
+        action = Gio.SimpleAction(name="manage-tools")
         action.connect("activate", lambda action, parameter: self.open_dialog())
         self.window.add_action(action)
 
-        self.gear_menu = self.extend_gear_menu("ext9")
-        item = Gio.MenuItem.new(_("Manage _External Tools..."), "win.manage_tools")
-        self.gear_menu.append_menu_item(item)
-        external_tools_submenu = Gio.Menu()
-        item = Gio.MenuItem.new_submenu(_("External _Tools"), external_tools_submenu)
-        self.gear_menu.append_menu_item(item)
-        external_tools_submenu_section = Gio.Menu()
-        external_tools_submenu.append_section(None, external_tools_submenu_section)
-
         # Create output console
         self._output_buffer = OutputPanel(self.plugin_info.get_data_dir(), self.window)
 
-        self.menu = ToolMenu(self._library, self.window, self._output_buffer, external_tools_submenu_section)
+        self.actions = ToolActions(self._library, self.window, self._output_buffer)
 
         bottom = self.window.get_bottom_panel()
-        image = Gtk.Image.new_from_icon_name("system-run-symbolic", Gtk.IconSize.MENU)
-        bottom.add_item(self._output_buffer.panel,
-                        "GeditExternalToolsShellOutput",
-                        _("Tool Output"),
-                        image)
+        bottom.add_titled(self._output_buffer.panel, "GeditExternalToolsShellOutput", _("Tool Output"))
 
     def do_update_state(self):
-        if self.menu is not None:
-            self.menu.filter(self.window.get_active_document())
+        if self.actions is not None:
+            self.actions.filter(self.window.get_active_document())
 
     def do_deactivate(self):
         self.window._external_tools_window_activatable = None
-        self.menu.deactivate()
-        self.window.remove_action("manage_tools")
+        self.actions.deactivate()
+        self.window.remove_action("manage-tools")
 
         bottom = self.window.get_bottom_panel()
-        bottom.remove_item(self._output_buffer.panel)
+        bottom.remove(self._output_buffer.panel)
 
     def open_dialog(self):
         if not self._manager:
@@ -196,6 +160,6 @@ class WindowActivatable(GObject.Object, Gedit.WindowActivatable):
 
     def on_manager_tools_updated(self, manager):
         for window in Gio.Application.get_default().get_windows():
-            window._external_tools_window_activatable.menu.update()
+            window._external_tools_window_activatable.actions.update()
 
 # ex:ts=4:et:
