@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -32,6 +31,7 @@
 
 #include <gedit/gedit-debug.h>
 #include <gedit/gedit-statusbar.h>
+#include <gedit/gedit-app.h>
 #include <gedit/gedit-window.h>
 #include <gedit/gedit-window-activatable.h>
 #include <gtksourceview/gtksource.h>
@@ -69,7 +69,6 @@ struct _GeditSpellPluginPrivate
 {
 	GeditWindow    *window;
 
-	GeditMenuExtension *menu;
 	guint           message_cid;
 	gulong          tab_added_id;
 	gulong          tab_removed_id;
@@ -138,7 +137,6 @@ gedit_spell_plugin_dispose (GObject *object)
 
 	gedit_debug_message (DEBUG_PLUGINS, "GeditSpellPlugin disposing");
 
-	g_clear_object (&plugin->priv->menu);
 	g_clear_object (&plugin->priv->window);
 
 	G_OBJECT_CLASS (gedit_spell_plugin_parent_class)->dispose (object);
@@ -1119,7 +1117,6 @@ gedit_spell_plugin_activate (GeditWindowActivatable *activatable)
 {
 	GeditSpellPlugin *plugin;
 	GeditSpellPluginPrivate *priv;
-	GMenuItem *item;
 	GList *views, *l;
 
 	gedit_debug (DEBUG_PLUGINS);
@@ -1132,21 +1129,6 @@ gedit_spell_plugin_activate (GeditWindowActivatable *activatable)
 	                                 G_N_ELEMENTS (action_entries),
 	                                 activatable);
 
-	priv->menu = gedit_window_activatable_extend_gear_menu (activatable,
-	                                                        "ext5");
-
-	item = g_menu_item_new (_("_Check Spelling..."), "win.check_spell");
-	gedit_menu_extension_append_menu_item (priv->menu, item);
-	g_object_unref (item);
-
-	item = g_menu_item_new (_("Set _Language..."), "win.config_spell");
-	gedit_menu_extension_append_menu_item (priv->menu, item);
-	g_object_unref (item);
-
-	item = g_menu_item_new (_("_Highlight Misspelled Words"), "win.auto_spell");
-	gedit_menu_extension_append_menu_item (priv->menu, item);
-	g_object_unref (item);
-
 	priv->message_cid = gtk_statusbar_get_context_id (GTK_STATUSBAR (gedit_window_get_statusbar (priv->window)),
 	                                                  "spell_plugin_message");
 
